
sncosmo.Bandpass
================

.. currentmodule:: sncosmo

.. autoclass:: Bandpass
   :show-inheritance:

   
   
   .. rubric:: Attributes

   .. autosummary::
   
         disp_eff
   
   


   
   
   .. rubric:: Methods Summary

   .. autosummary::
   
      ~Bandpass.to_unit
   
   


   
   

   .. rubric:: Methods Documentation

   
   .. automethod:: to_unit

   
   